diff --git a/docker/openvidu-basic-webinar/Dockerfile b/docker/openvidu-basic-webinar/Dockerfile
index 4b783452..8cde564f 100644
--- a/docker/openvidu-basic-webinar/Dockerfile
+++ b/docker/openvidu-basic-webinar/Dockerfile
@@ -9,8 +9,8 @@ RUN apk update && \
# Install basic-videoconference
RUN mkdir -p /opt/openvidu-basic-webinar && \
- wget -L -O /opt/openvidu-js-java.jar \
- "https://github.com/OpenVidu/openvidu-tutorials/releases/download/v${OPENVIDU_TUTORIALS_VERSION}/openvidu-js-java-${OPENVIDU_TUTORIALS_VERSION}.jar"
+ wget -L -O /opt/openvidu-roles-java.jar \
+ "https://github.com/OpenVidu/openvidu-tutorials/releases/download/v${OPENVIDU_TUTORIALS_VERSION}/openvidu-roles-java-${OPENVIDU_TUTORIALS_VERSION}.jar"
# Entrypoint
COPY ./entrypoint.sh /usr/local/bin
diff --git a/docker/openvidu-basic-webinar/entrypoint.sh b/docker/openvidu-basic-webinar/entrypoint.sh
index 70779f2e..1a1f2489 100644
--- a/docker/openvidu-basic-webinar/entrypoint.sh
+++ b/docker/openvidu-basic-webinar/entrypoint.sh
@@ -10,4 +10,4 @@ JAVA_PROPERTIES="-Djava.security.egd=file:/dev/./urandom"
[ ! -z "${OPENVIDU_SECRET}" ] && JAVA_PROPERTIES=" ${JAVA_PROPERTIES} -Dopenvidu.secret=${OPENVIDU_SECRET}"
[ ! -z "${APP_PORT}" ] && JAVA_PROPERTIES=" ${JAVA_PROPERTIES} -Dserver.port=${APP_PORT}"
-java ${JAVA_PROPERTIES} -jar /opt/openvidu-js-java.jar
+java ${JAVA_PROPERTIES} -jar /opt/openvidu-roles-java.jar
diff --git a/openvidu-android/build.gradle b/openvidu-android/build.gradle
index 0663994e..f817a65f 100644
--- a/openvidu-android/build.gradle
+++ b/openvidu-android/build.gradle
@@ -7,7 +7,7 @@ buildscript {
}
dependencies {
- classpath 'com.android.tools.build:gradle:7.2.1'
+ classpath 'com.android.tools.build:gradle:7.2.2'
// NOTE: Do not place your application dependencies here; they belong
// in the individual module build.gradle files
diff --git a/openvidu-angular/nginx.conf b/openvidu-angular/nginx.conf
new file mode 100644
index 00000000..36853fbb
--- /dev/null
+++ b/openvidu-angular/nginx.conf
@@ -0,0 +1,52 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream server-application {
+ server host.docker.internal:5000;
+ }
+ upstream client-application {
+ server host.docker.internal:4200;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Server application requests
+ location /api/ {
+ proxy_pass http://server-application;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass http://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-electron/nginx.conf b/openvidu-electron/nginx.conf
new file mode 100644
index 00000000..15ddfd16
--- /dev/null
+++ b/openvidu-electron/nginx.conf
@@ -0,0 +1,44 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream server-application {
+ server host.docker.internal:5000;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Server application requests
+ location /api/ {
+ proxy_pass http://server-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-fault-tolerance/src/main/resources/static/index.html b/openvidu-fault-tolerance/src/main/resources/static/index.html
index 21c9550a..27b02515 100644
--- a/openvidu-fault-tolerance/src/main/resources/static/index.html
+++ b/openvidu-fault-tolerance/src/main/resources/static/index.html
@@ -38,12 +38,12 @@
openvidu-fault-tolerance
diff --git a/openvidu-filters/README.md b/openvidu-filters/README.md
index 149bf24b..7624eb5b 100644
--- a/openvidu-filters/README.md
+++ b/openvidu-filters/README.md
@@ -17,7 +17,7 @@ Visit [docs.openvidu.io/en/stable/advanced-features/filters](http://docs.openvid
```bash
# Launch OpenVidu Server
-docker run --rm -d -p 4443:4443 -e openvidu.secret=MY_SECRET openvidu/openvidu-server-kms:2.21.0
+docker run -p 4443:4443 --rm -e OPENVIDU_SECRET=MY_SECRET openvidu/openvidu-dev:2.22.0
# Clone and serve openvidu-filters application
git clone https://github.com/OpenVidu/openvidu-tutorials.git
diff --git a/openvidu-filters/nginx.conf b/openvidu-filters/nginx.conf
new file mode 100644
index 00000000..b9bee005
--- /dev/null
+++ b/openvidu-filters/nginx.conf
@@ -0,0 +1,52 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream server-application {
+ server host.docker.internal:5000;
+ }
+ upstream client-application {
+ server host.docker.internal:8080;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Server application requests
+ location /api/ {
+ proxy_pass http://server-application;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass http://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-ionic-capacitor/ios/App/App.xcodeproj/project.pbxproj b/openvidu-ionic-capacitor/ios/App/App.xcodeproj/project.pbxproj
index 30a2d160..686b8685 100644
--- a/openvidu-ionic-capacitor/ios/App/App.xcodeproj/project.pbxproj
+++ b/openvidu-ionic-capacitor/ios/App/App.xcodeproj/project.pbxproj
@@ -122,8 +122,8 @@
504EC2FC1FED79650016851F /* Project object */ = {
isa = PBXProject;
attributes = {
- LastSwiftUpdateCheck = 0920;
- LastUpgradeCheck = 0920;
+ LastSwiftUpdateCheck = 920;
+ LastUpgradeCheck = 920;
TargetAttributes = {
504EC3031FED79650016851F = {
CreatedOnToolsVersion = 9.2;
@@ -359,6 +359,7 @@
SWIFT_ACTIVE_COMPILATION_CONDITIONS = DEBUG;
SWIFT_VERSION = 5.0;
TARGETED_DEVICE_FAMILY = "1,2";
+ MARKETING_VERSION = 1.0.0;
};
name = Debug;
};
@@ -378,6 +379,7 @@
SWIFT_ACTIVE_COMPILATION_CONDITIONS = "";
SWIFT_VERSION = 5.0;
TARGETED_DEVICE_FAMILY = "1,2";
+ MARKETING_VERSION = 1.0.0;
};
name = Release;
};
diff --git a/openvidu-ionic-capacitor/ios/App/App/Info.plist b/openvidu-ionic-capacitor/ios/App/App/Info.plist
index f870708a..e9cb3887 100644
--- a/openvidu-ionic-capacitor/ios/App/App/Info.plist
+++ b/openvidu-ionic-capacitor/ios/App/App/Info.plist
@@ -17,7 +17,7 @@
CFBundlePackageType
APPL
CFBundleShortVersionString
- 1.0
+ $(MARKETING_VERSION)
CFBundleVersion
1
LSRequiresIPhoneOS
@@ -30,9 +30,9 @@
NSCameraUsageDescription
This Application uses your camera to make video calls.
NSMicrophoneUsageDescription
- This Application uses your microphone to make calls.
+ This Application uses your microphone to make calls.
NSBluetoothAlwaysUsageDescription
- This Application uses your wireless headphones and microphone to make calls.
+ This Application uses your wireless headphones and microphone to make calls.
UILaunchStoryboardName
LaunchScreen
UIMainStoryboardFile
@@ -57,4 +57,4 @@
UIViewControllerBasedStatusBarAppearance
-
+
\ No newline at end of file
diff --git a/openvidu-ionic-capacitor/ios/App/App/capacitor.config.json b/openvidu-ionic-capacitor/ios/App/App/capacitor.config.json
index 183a6b3d..2cb63107 100644
--- a/openvidu-ionic-capacitor/ios/App/App/capacitor.config.json
+++ b/openvidu-ionic-capacitor/ios/App/App/capacitor.config.json
@@ -1,6 +1,14 @@
{
- "appId": "io.ionic.starter",
+ "appId": "io.openvidu.ionic",
"appName": "openvidu-ionic-capacitor",
"webDir": "www",
- "bundledWebRuntime": false
+ "bundledWebRuntime": false,
+ "android": {
+ "includePlugins": [
+ "cordova-plugin-android-permissions"
+ ]
+ },
+ "ios": {
+ "includePlugins": []
+ }
}
diff --git a/openvidu-ionic-capacitor/ios/App/Podfile b/openvidu-ionic-capacitor/ios/App/Podfile
index 9650e983..01e487a1 100644
--- a/openvidu-ionic-capacitor/ios/App/Podfile
+++ b/openvidu-ionic-capacitor/ios/App/Podfile
@@ -9,11 +9,7 @@ install! 'cocoapods', :disable_input_output_paths => true
def capacitor_pods
pod 'Capacitor', :path => '../../node_modules/@capacitor/ios'
pod 'CapacitorCordova', :path => '../../node_modules/@capacitor/ios'
- pod 'CapacitorApp', :path => '../../node_modules/@capacitor/app'
- pod 'CapacitorHaptics', :path => '../../node_modules/@capacitor/haptics'
- pod 'CapacitorKeyboard', :path => '../../node_modules/@capacitor/keyboard'
- pod 'CapacitorStatusBar', :path => '../../node_modules/@capacitor/status-bar'
- pod 'CordovaPlugins', :path => '../capacitor-cordova-ios-plugins'
+
end
target 'App' do
diff --git a/openvidu-ionic-capacitor/nginx.conf b/openvidu-ionic-capacitor/nginx.conf
index c837f720..8910de55 100644
--- a/openvidu-ionic-capacitor/nginx.conf
+++ b/openvidu-ionic-capacitor/nginx.conf
@@ -3,13 +3,13 @@ events {
}
http {
upstream openvidu-deployment {
- server localhost:4443;
+ server host.docker.internal:4443;
}
upstream server-application {
- server localhost:5000;
+ server host.docker.internal:5000;
}
upstream client-application {
- server localhost:8100;
+ server host.docker.internal:8100;
}
server {
listen 443 ssl;
diff --git a/openvidu-ionic/nginx.conf b/openvidu-ionic/nginx.conf
new file mode 100644
index 00000000..8910de55
--- /dev/null
+++ b/openvidu-ionic/nginx.conf
@@ -0,0 +1,52 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream server-application {
+ server host.docker.internal:5000;
+ }
+ upstream client-application {
+ server host.docker.internal:8100;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Server application requests
+ location /api/ {
+ proxy_pass http://server-application;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass http://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-ipcameras/nginx.conf b/openvidu-ipcameras/nginx.conf
new file mode 100644
index 00000000..20706215
--- /dev/null
+++ b/openvidu-ipcameras/nginx.conf
@@ -0,0 +1,44 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream client-application {
+ server host.docker.internal:8080;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass https://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-ipcameras/src/main/resources/application.properties b/openvidu-ipcameras/src/main/resources/application.properties
index 08d10a12..206641af 100644
--- a/openvidu-ipcameras/src/main/resources/application.properties
+++ b/openvidu-ipcameras/src/main/resources/application.properties
@@ -5,5 +5,5 @@ server.ssl.key-store-password: openvidu
server.ssl.key-store-type: JKS
server.ssl.key-alias: openvidu-selfsigned
-openvidu-url: https://localhost:4443/
+openvidu-url: http://localhost:4443/
openvidu-secret: MY_SECRET
\ No newline at end of file
diff --git a/openvidu-js-screen-share/nginx.conf b/openvidu-js-screen-share/nginx.conf
new file mode 100644
index 00000000..b9bee005
--- /dev/null
+++ b/openvidu-js-screen-share/nginx.conf
@@ -0,0 +1,52 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream server-application {
+ server host.docker.internal:5000;
+ }
+ upstream client-application {
+ server host.docker.internal:8080;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Server application requests
+ location /api/ {
+ proxy_pass http://server-application;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass http://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-js/nginx.conf b/openvidu-js/nginx.conf
new file mode 100644
index 00000000..b9bee005
--- /dev/null
+++ b/openvidu-js/nginx.conf
@@ -0,0 +1,52 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream server-application {
+ server host.docker.internal:5000;
+ }
+ upstream client-application {
+ server host.docker.internal:8080;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Server application requests
+ location /api/ {
+ proxy_pass http://server-application;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass http://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-library-react/nginx.conf b/openvidu-library-react/nginx.conf
new file mode 100644
index 00000000..da0c73b2
--- /dev/null
+++ b/openvidu-library-react/nginx.conf
@@ -0,0 +1,52 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream server-application {
+ server host.docker.internal:5000;
+ }
+ upstream client-application {
+ server host.docker.internal:3000;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Server application requests
+ location /api/ {
+ proxy_pass http://server-application;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass http://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-react-native/android/.project b/openvidu-react-native/android/.project
index 2cf2afe8..9cff4bf9 100644
--- a/openvidu-react-native/android/.project
+++ b/openvidu-react-native/android/.project
@@ -14,4 +14,15 @@
org.eclipse.buildship.core.gradleprojectnature
+
+
+ 1661252705943
+
+ 30
+
+ org.eclipse.core.resources.regexFilterMatcher
+ node_modules|.git|__CREATED_BY_JAVA_LANGUAGE_SERVER__
+
+
+
diff --git a/openvidu-react-native/android/.settings/org.eclipse.buildship.core.prefs b/openvidu-react-native/android/.settings/org.eclipse.buildship.core.prefs
index e8895216..2b6d83b9 100644
--- a/openvidu-react-native/android/.settings/org.eclipse.buildship.core.prefs
+++ b/openvidu-react-native/android/.settings/org.eclipse.buildship.core.prefs
@@ -1,2 +1,13 @@
+arguments=
+auto.sync=false
+build.scans.enabled=false
+connection.gradle.distribution=GRADLE_DISTRIBUTION(WRAPPER)
connection.project.dir=
eclipse.preferences.version=1
+gradle.user.home=
+java.home=/usr/lib/jvm/java-11-openjdk-amd64
+jvm.arguments=
+offline.mode=false
+override.workspace.settings=true
+show.console.view=true
+show.executions.view=true
diff --git a/openvidu-react/nginx.conf b/openvidu-react/nginx.conf
new file mode 100644
index 00000000..da0c73b2
--- /dev/null
+++ b/openvidu-react/nginx.conf
@@ -0,0 +1,52 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream server-application {
+ server host.docker.internal:5000;
+ }
+ upstream client-application {
+ server host.docker.internal:3000;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Server application requests
+ location /api/ {
+ proxy_pass http://server-application;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass http://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-recording-java/nginx.conf b/openvidu-recording-java/nginx.conf
new file mode 100644
index 00000000..500c543d
--- /dev/null
+++ b/openvidu-recording-java/nginx.conf
@@ -0,0 +1,44 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream client-application {
+ server host.docker.internal:5000;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass https://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-recording-java/src/main/resources/application.properties b/openvidu-recording-java/src/main/resources/application.properties
index ac9174a0..61bef2ed 100644
--- a/openvidu-recording-java/src/main/resources/application.properties
+++ b/openvidu-recording-java/src/main/resources/application.properties
@@ -6,5 +6,5 @@ server.ssl.key-store-type: JKS
server.ssl.key-alias: openvidu-selfsigned
spring.http.converters.preferred-json-mapper=gson
-openvidu.url: https://localhost:4443/
+openvidu.url: http://localhost:4443/
openvidu.secret: MY_SECRET
diff --git a/openvidu-recording-java/src/main/resources/static/index.html b/openvidu-recording-java/src/main/resources/static/index.html
index 5cd13268..15f476b0 100644
--- a/openvidu-recording-java/src/main/resources/static/index.html
+++ b/openvidu-recording-java/src/main/resources/static/index.html
@@ -39,7 +39,7 @@
title="GitHub Repository" target="_blank">
-
diff --git a/openvidu-recording-node/public/index.html b/openvidu-recording-node/public/index.html
index 821629be..89264c8a 100644
--- a/openvidu-recording-node/public/index.html
+++ b/openvidu-recording-node/public/index.html
@@ -39,7 +39,7 @@
title="GitHub Repository" target="_blank">
-
diff --git a/openvidu-recording-node/server.js b/openvidu-recording-node/server.js
index e3182882..775035b9 100644
--- a/openvidu-recording-node/server.js
+++ b/openvidu-recording-node/server.js
@@ -10,7 +10,7 @@ if (process.argv.length != 4) {
}
// For demo purposes we ignore self-signed certificate
process.env.NODE_TLS_REJECT_UNAUTHORIZED = "0"
-var port = process.env.PORT || 3000;
+var port = process.env.PORT || 5000;
var useSSL = (process.env.USE_SSL === 'false') ? false : true
diff --git a/openvidu-js-java/.gitignore b/openvidu-roles-java/.gitignore
similarity index 100%
rename from openvidu-js-java/.gitignore
rename to openvidu-roles-java/.gitignore
diff --git a/openvidu-js-java/LICENSE b/openvidu-roles-java/LICENSE
similarity index 100%
rename from openvidu-js-java/LICENSE
rename to openvidu-roles-java/LICENSE
diff --git a/openvidu-js-java/README.md b/openvidu-roles-java/README.md
similarity index 84%
rename from openvidu-js-java/README.md
rename to openvidu-roles-java/README.md
index 73fe13f0..c19ecf1c 100644
--- a/openvidu-js-java/README.md
+++ b/openvidu-roles-java/README.md
@@ -6,9 +6,9 @@
[![][OpenViduLogo]](http://openvidu.io)
-openvidu-js-java
+openvidu-roles-java
===
-Visit [docs.openvidu.io/en/stable/tutorials/openvidu-js-java/](http://docs.openvidu.io/en/stable/tutorials/openvidu-js-java/)
+Visit [docs.openvidu.io/en/stable/tutorials/openvidu-roles-java/](http://docs.openvidu.io/en/stable/tutorials/openvidu-roles-java/)
[OpenViduLogo]: https://secure.gravatar.com/avatar/5daba1d43042f2e4e85849733c8e5702?s=120
\ No newline at end of file
diff --git a/openvidu-js-java/docker/Dockerfile b/openvidu-roles-java/docker/Dockerfile
similarity index 78%
rename from openvidu-js-java/docker/Dockerfile
rename to openvidu-roles-java/docker/Dockerfile
index b09aea95..10e06ae5 100644
--- a/openvidu-js-java/docker/Dockerfile
+++ b/openvidu-roles-java/docker/Dockerfile
@@ -15,7 +15,7 @@ RUN apk update && \
# Install basic-webinar
RUN mkdir -p /opt/openvidu-basic-webinar
-COPY --from=build /basic-webinar/target/openvidu-js-java-*.jar /opt/openvidu-basic-webinar/openvidu-basic-webinar.jar
+COPY --from=build /basic-webinar/target/openvidu-roles-java-*.jar /opt/openvidu-basic-webinar/openvidu-basic-webinar.jar
# Entrypoint
COPY ./docker/entrypoint.sh /usr/local/bin
RUN chmod +x /usr/local/bin/entrypoint.sh
diff --git a/openvidu-js-java/docker/create_image.sh b/openvidu-roles-java/docker/create_image.sh
similarity index 100%
rename from openvidu-js-java/docker/create_image.sh
rename to openvidu-roles-java/docker/create_image.sh
diff --git a/openvidu-js-java/docker/docker-compose.override.yml b/openvidu-roles-java/docker/docker-compose.override.yml
similarity index 100%
rename from openvidu-js-java/docker/docker-compose.override.yml
rename to openvidu-roles-java/docker/docker-compose.override.yml
diff --git a/openvidu-js-java/docker/entrypoint.sh b/openvidu-roles-java/docker/entrypoint.sh
similarity index 100%
rename from openvidu-js-java/docker/entrypoint.sh
rename to openvidu-roles-java/docker/entrypoint.sh
diff --git a/openvidu-roles-java/nginx.conf b/openvidu-roles-java/nginx.conf
new file mode 100644
index 00000000..500c543d
--- /dev/null
+++ b/openvidu-roles-java/nginx.conf
@@ -0,0 +1,44 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream client-application {
+ server host.docker.internal:5000;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass https://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-js-java/pom.xml b/openvidu-roles-java/pom.xml
similarity index 93%
rename from openvidu-js-java/pom.xml
rename to openvidu-roles-java/pom.xml
index 30f82d4b..640ecfca 100644
--- a/openvidu-js-java/pom.xml
+++ b/openvidu-roles-java/pom.xml
@@ -4,12 +4,12 @@
4.0.0
io.openvidu
- openvidu-js-java
+ openvidu-roles-java
2.22.0
jar
- openvidu-js-java
- https://github.com/OpenVidu/openvidu-tutorials/tree/master/openvidu-js-java
+ openvidu-roles-java
+ https://github.com/OpenVidu/openvidu-tutorials/tree/master/openvidu-roles-java
org.springframework.boot
diff --git a/openvidu-js-java/src/main/java/io/openvidu/js/java/App.java b/openvidu-roles-java/src/main/java/io/openvidu/js/java/App.java
similarity index 100%
rename from openvidu-js-java/src/main/java/io/openvidu/js/java/App.java
rename to openvidu-roles-java/src/main/java/io/openvidu/js/java/App.java
diff --git a/openvidu-js-java/src/main/java/io/openvidu/js/java/LoginController.java b/openvidu-roles-java/src/main/java/io/openvidu/js/java/LoginController.java
similarity index 100%
rename from openvidu-js-java/src/main/java/io/openvidu/js/java/LoginController.java
rename to openvidu-roles-java/src/main/java/io/openvidu/js/java/LoginController.java
diff --git a/openvidu-js-java/src/main/java/io/openvidu/js/java/SessionController.java b/openvidu-roles-java/src/main/java/io/openvidu/js/java/SessionController.java
similarity index 100%
rename from openvidu-js-java/src/main/java/io/openvidu/js/java/SessionController.java
rename to openvidu-roles-java/src/main/java/io/openvidu/js/java/SessionController.java
diff --git a/openvidu-js-java/src/main/resources/application.properties b/openvidu-roles-java/src/main/resources/application.properties
similarity index 86%
rename from openvidu-js-java/src/main/resources/application.properties
rename to openvidu-roles-java/src/main/resources/application.properties
index 2463c1ef..2a7a3853 100644
--- a/openvidu-js-java/src/main/resources/application.properties
+++ b/openvidu-roles-java/src/main/resources/application.properties
@@ -5,5 +5,5 @@ server.ssl.key-store-password: openvidu
server.ssl.key-store-type: JKS
server.ssl.key-alias: openvidu-selfsigned
-openvidu.url: https://localhost:4443/
+openvidu.url: http://localhost:4443/
openvidu.secret: MY_SECRET
diff --git a/openvidu-js-java/src/main/resources/openvidu-selfsigned.jks b/openvidu-roles-java/src/main/resources/openvidu-selfsigned.jks
similarity index 100%
rename from openvidu-js-java/src/main/resources/openvidu-selfsigned.jks
rename to openvidu-roles-java/src/main/resources/openvidu-selfsigned.jks
diff --git a/openvidu-js-java/src/main/resources/static/app.js b/openvidu-roles-java/src/main/resources/static/app.js
similarity index 100%
rename from openvidu-js-java/src/main/resources/static/app.js
rename to openvidu-roles-java/src/main/resources/static/app.js
diff --git a/openvidu-js-java/src/main/resources/static/images/favicon.ico b/openvidu-roles-java/src/main/resources/static/images/favicon.ico
similarity index 100%
rename from openvidu-js-java/src/main/resources/static/images/favicon.ico
rename to openvidu-roles-java/src/main/resources/static/images/favicon.ico
diff --git a/openvidu-js-java/src/main/resources/static/images/openvidu_globe_bg_transp_cropped.png b/openvidu-roles-java/src/main/resources/static/images/openvidu_globe_bg_transp_cropped.png
similarity index 100%
rename from openvidu-js-java/src/main/resources/static/images/openvidu_globe_bg_transp_cropped.png
rename to openvidu-roles-java/src/main/resources/static/images/openvidu_globe_bg_transp_cropped.png
diff --git a/openvidu-js-java/src/main/resources/static/images/openvidu_grey_bg_transp_cropped.png b/openvidu-roles-java/src/main/resources/static/images/openvidu_grey_bg_transp_cropped.png
similarity index 100%
rename from openvidu-js-java/src/main/resources/static/images/openvidu_grey_bg_transp_cropped.png
rename to openvidu-roles-java/src/main/resources/static/images/openvidu_grey_bg_transp_cropped.png
diff --git a/openvidu-js-java/src/main/resources/static/images/openvidu_vert_white_bg_trans_cropped.png b/openvidu-roles-java/src/main/resources/static/images/openvidu_vert_white_bg_trans_cropped.png
similarity index 100%
rename from openvidu-js-java/src/main/resources/static/images/openvidu_vert_white_bg_trans_cropped.png
rename to openvidu-roles-java/src/main/resources/static/images/openvidu_vert_white_bg_trans_cropped.png
diff --git a/openvidu-js-java/src/main/resources/static/images/subscriber-msg.jpg b/openvidu-roles-java/src/main/resources/static/images/subscriber-msg.jpg
similarity index 100%
rename from openvidu-js-java/src/main/resources/static/images/subscriber-msg.jpg
rename to openvidu-roles-java/src/main/resources/static/images/subscriber-msg.jpg
diff --git a/openvidu-js-java/src/main/resources/static/index.html b/openvidu-roles-java/src/main/resources/static/index.html
similarity index 93%
rename from openvidu-js-java/src/main/resources/static/index.html
rename to openvidu-roles-java/src/main/resources/static/index.html
index 9399ddeb..72b068c7 100644
--- a/openvidu-js-java/src/main/resources/static/index.html
+++ b/openvidu-roles-java/src/main/resources/static/index.html
@@ -1,7 +1,7 @@
- openvidu-js-java
+ openvidu-roles-java
@@ -30,10 +30,10 @@
diff --git a/openvidu-js-java/src/main/resources/static/openvidu-browser-2.22.0.js b/openvidu-roles-java/src/main/resources/static/openvidu-browser-2.22.0.js
similarity index 100%
rename from openvidu-js-java/src/main/resources/static/openvidu-browser-2.22.0.js
rename to openvidu-roles-java/src/main/resources/static/openvidu-browser-2.22.0.js
diff --git a/openvidu-js-java/src/main/resources/static/style.css b/openvidu-roles-java/src/main/resources/static/style.css
similarity index 100%
rename from openvidu-js-java/src/main/resources/static/style.css
rename to openvidu-roles-java/src/main/resources/static/style.css
diff --git a/openvidu-js-java/src/test/java/io/openvidu/js/java/test/AppTest.java b/openvidu-roles-java/src/test/java/io/openvidu/js/java/test/AppTest.java
similarity index 100%
rename from openvidu-js-java/src/test/java/io/openvidu/js/java/test/AppTest.java
rename to openvidu-roles-java/src/test/java/io/openvidu/js/java/test/AppTest.java
diff --git a/openvidu-js-node/.gitignore b/openvidu-roles-node/.gitignore
similarity index 100%
rename from openvidu-js-node/.gitignore
rename to openvidu-roles-node/.gitignore
diff --git a/openvidu-js-node/LICENSE b/openvidu-roles-node/LICENSE
similarity index 100%
rename from openvidu-js-node/LICENSE
rename to openvidu-roles-node/LICENSE
diff --git a/openvidu-js-node/README.md b/openvidu-roles-node/README.md
similarity index 84%
rename from openvidu-js-node/README.md
rename to openvidu-roles-node/README.md
index b50853cd..8e57e05c 100644
--- a/openvidu-js-node/README.md
+++ b/openvidu-roles-node/README.md
@@ -6,9 +6,9 @@
[![][OpenViduLogo]](http://openvidu.io)
-openvidu-js-node
+openvidu-roles-node
===
-Visit [docs.openvidu.io/en/stable/tutorials/openvidu-js-node/](http://docs.openvidu.io/en/stable/tutorials/openvidu-js-node/)
+Visit [docs.openvidu.io/en/stable/tutorials/openvidu-roles-node/](http://docs.openvidu.io/en/stable/tutorials/openvidu-roles-node/)
[OpenViduLogo]: https://secure.gravatar.com/avatar/5daba1d43042f2e4e85849733c8e5702?s=120
\ No newline at end of file
diff --git a/openvidu-roles-node/nginx.conf b/openvidu-roles-node/nginx.conf
new file mode 100644
index 00000000..500c543d
--- /dev/null
+++ b/openvidu-roles-node/nginx.conf
@@ -0,0 +1,44 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream client-application {
+ server host.docker.internal:5000;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass https://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-js-node/openviducert.pem b/openvidu-roles-node/openviducert.pem
similarity index 100%
rename from openvidu-js-node/openviducert.pem
rename to openvidu-roles-node/openviducert.pem
diff --git a/openvidu-js-node/openvidukey.pem b/openvidu-roles-node/openvidukey.pem
similarity index 100%
rename from openvidu-js-node/openvidukey.pem
rename to openvidu-roles-node/openvidukey.pem
diff --git a/openvidu-js-node/package-lock.json b/openvidu-roles-node/package-lock.json
similarity index 99%
rename from openvidu-js-node/package-lock.json
rename to openvidu-roles-node/package-lock.json
index 26155383..fcb48ebc 100644
--- a/openvidu-js-node/package-lock.json
+++ b/openvidu-roles-node/package-lock.json
@@ -1,11 +1,11 @@
{
- "name": "openvidu-js-node",
+ "name": "openvidu-roles-node",
"version": "2.22.0",
"lockfileVersion": 2,
"requires": true,
"packages": {
"": {
- "name": "openvidu-js-node",
+ "name": "openvidu-roles-node",
"version": "2.22.0",
"license": "Apache-2.0",
"dependencies": {
diff --git a/openvidu-js-node/package.json b/openvidu-roles-node/package.json
similarity index 94%
rename from openvidu-js-node/package.json
rename to openvidu-roles-node/package.json
index f7732416..a03c2c4f 100644
--- a/openvidu-js-node/package.json
+++ b/openvidu-roles-node/package.json
@@ -1,5 +1,5 @@
{
- "name": "openvidu-js-node",
+ "name": "openvidu-roles-node",
"version": "2.22.0",
"description": "",
"main": "server.js",
diff --git a/openvidu-js-node/public/app.js b/openvidu-roles-node/public/app.js
similarity index 100%
rename from openvidu-js-node/public/app.js
rename to openvidu-roles-node/public/app.js
diff --git a/openvidu-js-node/public/images/favicon.ico b/openvidu-roles-node/public/images/favicon.ico
similarity index 100%
rename from openvidu-js-node/public/images/favicon.ico
rename to openvidu-roles-node/public/images/favicon.ico
diff --git a/openvidu-js-node/public/images/openvidu_globe_bg_transp_cropped.png b/openvidu-roles-node/public/images/openvidu_globe_bg_transp_cropped.png
similarity index 100%
rename from openvidu-js-node/public/images/openvidu_globe_bg_transp_cropped.png
rename to openvidu-roles-node/public/images/openvidu_globe_bg_transp_cropped.png
diff --git a/openvidu-js-node/public/images/openvidu_grey_bg_transp_cropped.png b/openvidu-roles-node/public/images/openvidu_grey_bg_transp_cropped.png
similarity index 100%
rename from openvidu-js-node/public/images/openvidu_grey_bg_transp_cropped.png
rename to openvidu-roles-node/public/images/openvidu_grey_bg_transp_cropped.png
diff --git a/openvidu-js-node/public/images/openvidu_vert_white_bg_trans_cropped.png b/openvidu-roles-node/public/images/openvidu_vert_white_bg_trans_cropped.png
similarity index 100%
rename from openvidu-js-node/public/images/openvidu_vert_white_bg_trans_cropped.png
rename to openvidu-roles-node/public/images/openvidu_vert_white_bg_trans_cropped.png
diff --git a/openvidu-js-node/public/images/subscriber-msg.jpg b/openvidu-roles-node/public/images/subscriber-msg.jpg
similarity index 100%
rename from openvidu-js-node/public/images/subscriber-msg.jpg
rename to openvidu-roles-node/public/images/subscriber-msg.jpg
diff --git a/openvidu-js-node/public/index.html b/openvidu-roles-node/public/index.html
similarity index 93%
rename from openvidu-js-node/public/index.html
rename to openvidu-roles-node/public/index.html
index 8dcd3045..056c57ff 100644
--- a/openvidu-js-node/public/index.html
+++ b/openvidu-roles-node/public/index.html
@@ -1,7 +1,7 @@
- openvidu-js-node
+ openvidu-roles-node
@@ -30,10 +30,10 @@
diff --git a/openvidu-js-node/public/openvidu-browser-2.22.0.js b/openvidu-roles-node/public/openvidu-browser-2.22.0.js
similarity index 100%
rename from openvidu-js-node/public/openvidu-browser-2.22.0.js
rename to openvidu-roles-node/public/openvidu-browser-2.22.0.js
diff --git a/openvidu-js-node/public/style.css b/openvidu-roles-node/public/style.css
similarity index 100%
rename from openvidu-js-node/public/style.css
rename to openvidu-roles-node/public/style.css
diff --git a/openvidu-js-node/server.js b/openvidu-roles-node/server.js
similarity index 100%
rename from openvidu-js-node/server.js
rename to openvidu-roles-node/server.js
diff --git a/openvidu-virtual-background/nginx.conf b/openvidu-virtual-background/nginx.conf
new file mode 100644
index 00000000..67e5b966
--- /dev/null
+++ b/openvidu-virtual-background/nginx.conf
@@ -0,0 +1,39 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream server-application {
+ server host.docker.internal:5000;
+ }
+ upstream client-application {
+ server host.docker.internal:8080;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # Server application requests
+ location /api/ {
+ proxy_pass http://server-application;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass http://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/openvidu-vue/nginx.conf b/openvidu-vue/nginx.conf
new file mode 100644
index 00000000..b9bee005
--- /dev/null
+++ b/openvidu-vue/nginx.conf
@@ -0,0 +1,52 @@
+events {
+ worker_connections 512;
+}
+http {
+ upstream openvidu-deployment {
+ server host.docker.internal:4443;
+ }
+ upstream server-application {
+ server host.docker.internal:5000;
+ }
+ upstream client-application {
+ server host.docker.internal:8080;
+ }
+ server {
+ listen 443 ssl;
+ ssl_certificate /etc/nginx/certs/cert.pem;
+ ssl_certificate_key /etc/nginx/certs/key.pem;
+
+ proxy_set_header Host $host;
+ proxy_set_header X-Real-IP $remote_addr;
+ proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
+ proxy_set_header X-Forwarded-Proto $scheme;
+ proxy_set_header X-Forwarded-Proto https;
+ proxy_headers_hash_bucket_size 512;
+ proxy_redirect off;
+
+ # Websockets
+ proxy_http_version 1.1;
+ proxy_set_header Upgrade $http_upgrade;
+ proxy_set_header Connection "upgrade";
+
+ # OpenVidu deployment API
+ location /openvidu/api {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # OpenVidu WebSocket
+ location ~ /openvidu$ {
+ proxy_pass http://openvidu-deployment;
+ }
+
+ # Server application requests
+ location /api/ {
+ proxy_pass http://server-application;
+ }
+
+ # Client application requests
+ location / {
+ proxy_pass http://client-application;
+ }
+ }
+}
\ No newline at end of file
diff --git a/update-tutorials.sh b/update-tutorials.sh
index dd195950..bac9e081 100755
--- a/update-tutorials.sh
+++ b/update-tutorials.sh
@@ -36,8 +36,7 @@ NPM_TUTORIALS="openvidu-angular
openvidu-react
openvidu-library-react
openvidu-ionic
- openvidu-js-node
- openvidu-mvc-node
+ openvidu-roles-node
openvidu-recording-node
openvidu-react-native
openvidu-electron
@@ -45,8 +44,7 @@ NPM_TUTORIALS="openvidu-angular
openvidu-call/openvidu-call-front
openvidu-call/openvidu-call-back"
-MAVEN_TUTORIALS="openvidu-js-java
- openvidu-mvc-java
+MAVEN_TUTORIALS="openvidu-roles-java
openvidu-recording-java
openvidu-ipcameras"
@@ -69,7 +67,7 @@ find . -type f -name 'package.json' -exec sed -i "s/file:openvidu-react-native-a
# If server SDKs must be udpated
if [[ -n "$FROM_VERSION_SDK" && -n "$TO_VERSION_SDK" ]]; then
# Updating openvidu-node-client dependencies in package.json files [openvidu-js-node, openvidu-mvc-node, openvidu-recording-node]
find . -type f -name 'package.json' -exec sed -i "s/\"openvidu-node-client\": \"$FROM_VERSION_SDK\"/\"openvidu-node-client\": \"$TO_VERSION_SDK\"/" {} \;
# Updating openvidu-java-client dependencies in pom.xml files
@@ -69,7 +67,7 @@ find . -type f -name 'package.json' -exec sed -i "s/file:openvidu-react-native-a
# If server SDKs must be udpated
if [[ -n "$FROM_VERSION_SDK" && -n "$TO_VERSION_SDK" ]]; then
- # Updating openvidu-node-client dependencies in package.json files [openvidu-js-node, openvidu-mvc-node, openvidu-recording-node]
+ # Updating openvidu-node-client dependencies in package.json files [openvidu-roles-node, openvidu-recording-node]
find . -type f -name 'package.json' -exec sed -i "s/\"openvidu-node-client\": \"$FROM_VERSION_SDK\"/\"openvidu-node-client\": \"$TO_VERSION_SDK\"/" {} \;
# Updating openvidu-java-client dependencies in pom.xml files